Documentation
¶
Overview ¶
Package cmd implements the council CLI commands using cobra.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func LookupPersona ¶
LookupPersona finds a curated persona by name or ID (case-insensitive). Returns nil if not found.
func SuggestSimilar ¶
SuggestSimilar finds the closest persona match using edit distance. Returns nil if no close match (distance > 3), if exact match exists, or if the input is too short to match reliably. The second return value is the edit distance of the match.
Types ¶
type AICheckResult ¶
type AICheckResult struct {
Command string `json:"command"`
Status string `json:"status"` // "ok", "info"
Message string `json:"message,omitempty"`
}
AICheckResult represents the AI integration check
type CheckResult ¶
type CheckResult struct {
Name string `json:"name"`
Status string `json:"status"` // "ok", "error", "info"
Message string `json:"message,omitempty"`
Details []string `json:"details,omitempty"`
}
CheckResult represents a single health check
type DoctorResult ¶
type DoctorResult struct {
Healthy bool `json:"healthy"`
Checks []CheckResult `json:"checks"`
SyncTargets []SyncCheckResult `json:"sync_targets,omitempty"`
AICommand *AICheckResult `json:"ai_integration,omitempty"`
}
DoctorResult holds the complete health check results
type PersonaJSON ¶
type PersonaJSON struct {
ID string `json:"id"`
Name string `json:"name"`
Category string `json:"category"`
Focus string `json:"focus"`
Philosophy string `json:"philosophy,omitempty"`
Principles []string `json:"principles,omitempty"`
RedFlags []string `json:"red_flags,omitempty"`
Tensions []expert.Tension `json:"tensions,omitempty"`
Triggers []string `json:"triggers,omitempty"`
}
PersonaJSON is a flattened persona with category
Click to show internal directories.
Click to hide internal directories.